>fragment1
TACAGAGAGTGCGAGCGTTAATCGGATTTACTGGGCGTAAAGCGTGCGTAGGCGGCTTTTTAAGTCGGATGTGAAATCCCTGAGCTTAACTTAGGAATTG
>fragment2
TACGGGGGGGGCAAGCGTTATTCGGAATTACTGGGCGTAAAGGGCATGTAGGCTGCCAATCGCCACCTCTGCTTGAAGAAAACTGTAAATCTGGTCCTGA
>fragment3
GACGAACCGTACTAACGTTATTCGGAATTACTGGGCTTAAAGGGTGCGTAGGCGGTGCGGAAAGTTGGGTGTGAAATACCTCGGCTCAACCGAGGAACAG
>fragment4
TACAGAGGGTGCAAGCGTTGTTCGGAATCATTGGGCGTAAAGCGCGTGTAGGCGGCCGGGCAAGTCGCGTGTGAAATCCGTCGGCTCAACCGACGAAGTG
>fragment5
TACGTAGGTGGCAAGCGTTGTCCGGATTTACTGGGCGTAAAGCGTATGTAGGCGGATGTTTAAGTAGGAAGTGAAAGGTCAGAGCTCAACTCTGACACTG
>fragment6
GACAGGGGGCTCAAGCGTTAATCGGAATCACTGGGCTTAAAGGGTGCGCAGGCGGCCCGTCAAGCGTTCTGTGAAAGCCCCCGGCTCAACCGGGGAACAG
>fragment7
TACGTAGGTGGCAAGCGTTATCCGGAATTATTGGGCGTAAAGGGTGCGTAGGCGGCTGAATAAGTCTGAGGTAAAAGCCCGTGGCTCAACCATGGTAAGC
>fragment8
TACGTAGGTGACAAGCGTTGTCCGGATTTATTGGGCGTAAAGCGAGCGCAGGCGGTCTTTTAAGTCTGATGTGAAAGCCCACGGCTCAACCGTGGAGGGG
>fragment9
TACGTAGGTGGCAAGCGTTGTCCGGAATTATTGGGTGTAAAGCGCGCGCAGGTGGTTTAATAAGTCTGATGTGAAAGCCCACGGCCCAACCGTGGAGGGT
>fragment10
CCTCAGAATCTCGTATGCCGTCTTCTGCTTGATTAGATACCCTGGTAGTCCGGCTGACTGACTGGCAACCTCAGAATCTCGTATGCCGTCTTCTGCTTGA
